@@ -12,6 +12,7 @@
 #include <KActionCollection>
 #include <KComboBox>
 #include <KConfigGroup>
+#include <KGlobalAccel>
 #include <KLocalizedString>
 #include <KToggleAction>
 
@@ -25,6 +26,7 @@
 #include "view/torrentsearchbar.h"
 #include "view/view.h"
 #include <groups/groupmanager.h>
+#include <groups/torrentgroup.h>
 #include <gui/tabbarwidget.h>
 #include <util/log.h>
 
@@ -54,10 +56,16 @@ TorrentActivity::TorrentActivity(Core *core, GUI *gui, QWidget *parent)
     group_switcher = new GroupSwitcher(view, core->getGroupManager(), this);
     connect(core->getQueueManager(), &QueueManager::queueOrdered, this, &TorrentActivity::queueOrdered);
 
+    auto separator = new QFrame(this);
+    separator->setLineWidth(1);
+    separator->setFixedHeight(1);
+    separator->setFrameShape(QFrame::HLine);
+
     QVBoxLayout *vlayout = new QVBoxLayout(view_part);
     vlayout->setSpacing(0);
     vlayout->setContentsMargins(0, 0, 0, 0);
     vlayout->addWidget(group_switcher);
+    vlayout->addWidget(separator);
     vlayout->addWidget(search_bar);
     vlayout->addWidget(view);
 
@@ -65,6 +73,7 @@ TorrentActivity::TorrentActivity(Core *core, GUI *gui, QWidget *parent)
     group_view->setupActions(part()->actionCollection());
     connect(group_view, &GroupView::currentGroupChanged, group_switcher, &GroupSwitcher::currentGroupChanged);
     connect(group_view, &GroupView::openTab, group_switcher, &GroupSwitcher::addTab);
+    connect(group_view, &GroupView::addTorrentSelectionToGroup, this, &TorrentActivity::addTorrentSelectionToGroup);
 
     setupActions();
 
@@ -111,9 +120,9 @@ void TorrentActivity::setupActions()
 
     queue_suspend_action = new KToggleAction(QIcon::fromTheme(QStringLiteral("kt-pause")), i18n("Suspend Torrents"), this);
     ac->addAction(QStringLiteral("queue_suspend"), queue_suspend_action);
-    ac->setDefaultShortcut(queue_suspend_action, QKeySequence(Qt::SHIFT + Qt::Key_P));
+    ac->setDefaultShortcut(queue_suspend_action, QKeySequence(Qt::SHIFT | Qt::Key_P));
     queue_suspend_action->setToolTip(i18n("Suspend all running torrents"));
-    // KF5 queue_suspend_action->setGlobalShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_P));
+    KGlobalAccel::setGlobalShortcut(queue_suspend_action, QKeySequence(Qt::ALT | Qt::SHIFT | Qt::Key_P));
     connect(queue_suspend_action, &KToggleAction::toggled, this, &TorrentActivity::suspendQueue);
 
     show_group_view_action = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-list-tree")), i18n("Group View"), this);
@@ -125,7 +134,7 @@ void TorrentActivity::setupActions()
     filter_torrent_action->setToolTip(i18n("Filter torrents based on filter string"));
     connect(filter_torrent_action, &QAction::triggered, search_bar, &TorrentSearchBar::showBar);
     ac->addAction(QStringLiteral("filter_torrent"), filter_torrent_action);
-    ac->setDefaultShortcut(filter_torrent_action, QKeySequence(Qt::CTRL + Qt::Key_F));
+    ac->setDefaultShortcut(filter_torrent_action, QKeySequence(Qt::CTRL | Qt::Key_F));
 
     view->setupActions(ac);
 }
@@ -142,7 +151,7 @@ void TorrentActivity::removeToolWidget(QWidget *widget)
 
 void TorrentActivity::loadState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("TorrentActivitySplitters");
+    KConfigGroup g = cfg->group(QStringLiteral("TorrentActivitySplitters"));
     if (vsplit) {
         QByteArray data;
         data = QByteArray::fromBase64(g.readEntry("vsplit", data));
@@ -175,7 +184,7 @@ void TorrentActivity::saveState(KSharedConfigPtr cfg)
     tool_views->saveState(cfg, QStringLiteral("TorrentActivityBottomTabBar"));
     magnet_view->saveState(cfg);
 
-    KConfigGroup g = cfg->group("TorrentActivitySplitters");
+    KConfigGroup g = cfg->group(QStringLiteral("TorrentActivitySplitters"));
     if (vsplit) {
         QByteArray data = vsplit->saveState();
         g.writeEntry("vsplit", data.toBase64());
@@ -257,6 +266,15 @@ void TorrentActivity::queueOrdered()
     group_switcher->updateGroupCount();
 }
 
+void TorrentActivity::addTorrentSelectionToGroup(TorrentGroup *g)
+{
+    QList<TorrentInterface *> sel;
+    view->getSelection(sel);
+    for (TorrentInterface *ti : std::as_const(sel)) {
+        g->addTorrent(ti, false);
+    }
+    core->getGroupManager()->saveGroups();
+}
 }
 
 #include "moc_torrentactivity.cpp"
